#!/bin/bash
# Código de estado que devuelve:
# 0: si ha desmontado algún recurso y todo ha funcionado bien
# Devolverá en la salida estándar si ha desmontado algo o no mediante la cadena DESMONTA

. /etc/default/vx-dga-variables/vx-dga-variables-general.conf

FICHFUNCS="/usr/bin/vx-funcs-bash"
[ -f "${FICHFUNCS}" ] && . "${FICHFUNCS}"

vx-colorear_echo "magenta" "[$(vx-fecha)] NFS-SHARE: Desmontando Recursos" | sudo vx-auditar-syslog
ERROR=false
for VAR in "$@"; do
    RECURSO=$(echo "${VAR}" | cut -d":" -f2)
    # Chequeamos que el recurso está montado, asociado a nfs y a nuestro servidor caché
    ! ( grep "^${IPCACHE}.* nfs .*" /proc/mounts | grep "$RECURSO" > /dev/null 2>&1 ) && continue
    echo "Se va a desmontar el recurso: $RECURSO"
    if umount -lf "${RECURSO}" ; then
        [ -z "$(ls -A "${RECURSO}" )" ] && rmdir --ignore-fail-on-non-empty "${RECURSO}"
        vx-colorear_echo "verde" "Desmontado de forma correcta: $RECURSO"
    else
        ERROR=true
    fi
done

${ERROR} && vx-colorear_echo "magenta" "[$(vx-fecha)] NFS-SHARE: Error al desmontar los recursos" | sudo vx-auditar-syslog \
|| vx-colorear_echo "magenta" "[$(vx-fecha)] NFS-SHARE: Se han desmontado los recursos correctamente" | sudo vx-auditar-syslog

exit 0
